@@ -6,7 +6,7 @@ from .postagger import POSTagger
 from .stemmer import FindStems
 from .tokenizer import Tokenizer
 from .token_merger import ClassifierChunkParser
-from .spell_checker import SpellCheck
+# from .spell_checker import SpellCheck
 from .char_normalizer import Char_Normalizer
 from .date2string import Date2String
 from .time2string import Time2String
